package holmos.webtest.junitextentions.parameters.getter;

import holmos.webtest.junitextentions.HolmosRunner;
import holmos.webtest.junitextentions.annotations.Source;
import holmos.webtest.junitextentions.parameters.filepathanalysis.analysisimp.DefaultDataFilePathAnalysisRobot;

/**
 * 构造参数数据获取器的工厂方法
 * 
 * @author 吴银龙(sunshine307087558@gmail.com)
 * */
public class DataGetterFactory {
	/**
	 * 根据标志字符窜获取不同的Getter信息
	 * @param mark 标志字符窜,就是sql查询字符窜或者文件路径信息
	 * */
	public static DataGetter getDataGetter(Source source){
		if(null==source)return null;
		if(source.selector()!=null&&source.selector().trim().startsWith("select "))
			return new DatabaseDataGetter(source.selector().trim());
		else if(source.className()!=null){
			return new ObjectDataGetter(source.className().trim());
		}
		else{
			String mark=source.file().trim();
			String filePath=new DefaultDataFilePathAnalysisRobot().analysis(
					HolmosRunner.getTestClassForGetter(), mark).substring(1);
			if(mark.endsWith(".xls")||mark.endsWith(".xlsx"))
				return new ExcelDataGetter(filePath);
			else if(mark.endsWith(".csv"))
				return new CSVDataGetter(filePath);
			else if(mark.endsWith(".xml"))
				return new XMLDataGetter(filePath);
			else if(mark.endsWith(".properties"))
				return new PropertiesDataGetter(filePath);
		}
		return null;
	}
	public static ExcelDataGetter getExcelDataGetter(String excelFilePath){
		return new ExcelDataGetter(excelFilePath);
	}
	public static CSVDataGetter getCVSDataGetter(String CVSFilePath){
		return new CSVDataGetter(CVSFilePath);
	}
	public static DatabaseDataGetter getDatabaseDataGetter(String selectSql){
		return new DatabaseDataGetter(selectSql);
	}
	public static PropertiesDataGetter getPropertiesDataGetter(String propertiesFilePath){
		return new PropertiesDataGetter(propertiesFilePath);
	}
	public static XMLDataGetter getXmlDataGetter(String XMLFilePath){
		return new XMLDataGetter(XMLFilePath);
	}
	
}
